summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorGary Kramlich <grim@reaperworld.com>2019-05-20 21:50:28 -0500
committerGary Kramlich <grim@reaperworld.com>2019-05-20 21:50:28 -0500
commitab69e84f9789de2fadb6ccd28f5eb49a3fc83713 (patch)
treea2ef358c8460d43cc5315ce1c543afa2e3341e37
parent474f9277b29fc870b005cc046b5889c06b1c7635 (diff)
downloadpidgin-ab69e84f9789de2fadb6ccd28f5eb49a3fc83713.tar.gz
remove a few more references to webview
-rw-r--r--pidgin/gtkstatusbox.c16
1 files changed, 3 insertions, 13 deletions
diff --git a/pidgin/gtkstatusbox.c b/pidgin/gtkstatusbox.c
index d640200050..18794f93d5 100644
--- a/pidgin/gtkstatusbox.c
+++ b/pidgin/gtkstatusbox.c
@@ -1053,18 +1053,8 @@ combo_box_scroll_event_cb(GtkWidget *w, GdkEventScroll *event, gpointer data)
return TRUE;
}
-// static gboolean
-// webview_scroll_event_cb(GtkWidget *w, GdkEventScroll *event, PidginWebView *webview)
-// {
-// if (event->direction == GDK_SCROLL_UP)
-// pidgin_webview_page_up(webview);
-// else if (event->direction == GDK_SCROLL_DOWN)
-// pidgin_webview_page_down(webview);
-// return TRUE;
-// }
-
static gboolean
-webview_remove_focus(GtkWidget *w, GdkEventKey *event, PidginStatusBox *status_box)
+editor_remove_focus(GtkWidget *w, GdkEventKey *event, PidginStatusBox *status_box)
{
if (event->keyval == GDK_KEY_Return || event->keyval == GDK_KEY_KP_Enter) {
remove_typing_cb(status_box);
@@ -1765,7 +1755,7 @@ pidgin_status_box_init (PidginStatusBox *status_box)
g_signal_connect(G_OBJECT(status_box->toggle_button), "button-press-event",
G_CALLBACK(toggled_cb), status_box);
g_signal_connect(G_OBJECT(status_box->view), "key-press-event",
- G_CALLBACK(webview_remove_focus), status_box);
+ G_CALLBACK(editor_remove_focus), status_box);
gtk_widget_set_parent(status_box->vbox, GTK_WIDGET(status_box));
gtk_widget_show_all(status_box->vbox);
@@ -1828,7 +1818,7 @@ pidgin_status_box_get_preferred_height(GtkWidget *widget, gint *minimum_height,
*minimum_height = MAX(*minimum_height, 34) + border_width * 2;
*natural_height = MAX(*natural_height, 34) + border_width * 2;
/* If the gtkwebview is visible, then add some additional padding */
if (PIDGIN_STATUS_BOX(widget)->editor_visible) {
gtk_widget_get_preferred_height(PIDGIN_STATUS_BOX(widget)->vbox,
&box_min_height, &box_nat_height);
@@ -1828,7 +1818,7 @@ pidgin_status_box_get_preferred_height(GtkWidget *widget, gint *minimum_height,
*minimum_height = MAX(*minimum_height, 34) + border_width * 2;
*natural_height = MAX(*natural_height, 34) + border_width * 2;
- /* If the gtkwebview is visible, then add some additional padding */
+ /* If the editor is visible, then add some additional padding */
if (PIDGIN_STATUS_BOX(widget)->editor_visible) {
gtk_widget_get_preferred_height(PIDGIN_STATUS_BOX(widget)->vbox,